from .Displayable import Displayable
from ..DisplayOptions.AssemblyDisplayOptions import AssemblyDisplayOptions
from ..DisplayOptions.PartDisplayOptions import PartDisplayOptions
from ..OdbDisplay.OdbDisplay import OdbDisplay
from ..UtilityAndView.View import View
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class Layer:
    """Objects can be superimposed by displaying them in different layers of a viewport.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            session.viewports[name].layers[name]
    """

    #: A :py:class:`~abaqus.Canvas.Displayable.Displayable` object specifying the object to be displayed. The
    #: Displayable type is an abstract generalization. The concrete possible types are Part, Assembly,
    #: ConstrainedSketch, Odb, or XYPlot.
    displayedObject: Displayable = Displayable()

    #: A :py:class:`~abaqus.UtilityAndView.View.View` object specifying the object that controls viewing of the layer.
    view: View = None

    #: An :py:class:`~abaqus.OdbDisplay.OdbDisplay.OdbDisplay` object specifying the display options for the Odb object.
    odbDisplay: OdbDisplay = OdbDisplay()

    #: A :py:class:`~abaqus.DisplayOptions.PartDisplayOptions.PartDisplayOptions` object specifying the display options
    #: for the Part object.
    partDisplay: PartDisplayOptions = PartDisplayOptions()

    #: An :py:class:`~abaqus.DisplayOptions.AssemblyDisplayOptions.AssemblyDisplayOptions` object specifying the
    #: display options for the Assembly object.
    assemblyDisplay: AssemblyDisplayOptions = AssemblyDisplayOptions()

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the layer to copy.
    copyViewName: str = ""

    @abaqus_method_doc
    def __init__(self, name: str, copyViewName: str = ""):
        """This method creates a Layer object in the Layer repository.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                session.viewports[name].Layer

        Parameters
        ----------
        name
            A String specifying the repository key.
        copyViewName
            A String specifying the name of the layer to copy.

        Returns
        -------
        Layer
            A :py:class:`~abaqus.Canvas.Layer.Layer` object.
        """
        self.name = name
        self.copyViewName = copyViewName

    @abaqus_method_doc
    def moveBefore(self, name: str):
        """This method moves the layer object before another object in the layer repository.

        Parameters
        ----------
        name
            A String specifying the name of the other Layer object.
        """
        # TODO: implement this method
        ...

    @abaqus_method_doc
    def moveAfter(self, name: str):
        """This method moves the layer object after another object in the layer repository.

        Parameters
        ----------
        name
            A String specifying the name of the other Layer object.
        """
        # TODO: implement this method
        ...



import typing

from .BoundaryCondition import BoundaryCondition
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class ElectricPotentialBC(BoundaryCondition):
    """The ElectricPotentialBC object stores the data for an electrical potential boundary
    condition.
    The ElectricPotentialBC object is derived from the BoundaryCondition object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].boundaryConditions[name]
    """

    #: A String specifying the boundary condition repository key.
    name: str = ""

    #: A SymbolicConstant specifying how the boundary condition is distributed spatially.
    #: Possible values are UNIFORM, USER_DEFINED, and FIELD. The default value is UNIFORM.
    distributionType: SymbolicConstant = UNIFORM

    #: A String specifying the name of the AnalyticalField object associated with this boundary
    #: condition. The **fieldName** argument applies only when **distributionType** = FIELD. The
    #: default value is an empty string.
    fieldName: str = ""

    #: A SymbolicConstant specifying the category of the boundary condition. Possible values
    #: are MECHANICAL and THERMAL.
    category: SymbolicConstant = None

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
    region: Region = Region()

    #: None or a DatumCsys object specifying the local coordinate system of the boundary
    #: condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
    #: in the global coordinate system. The default value is None.
    localCsys: str = None

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        region: Region,
        fieldName: str = "",
        magnitude: float = 0,
        distributionType: SymbolicConstant = UNIFORM,
        amplitude: str = UNSET,
        fixed: Boolean = OFF,
    ):
        """This method creates an ElectricPotentialBC object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].ElectricPotentialBC

        Parameters
        ----------
        name
            A String specifying the boundary condition repository key.
        createStepName
            A String specifying the name of the step in which the boundary condition is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
        fieldName
            A String specifying the name of the AnalyticalField object associated with this boundary
            condition. The **fieldName** argument applies only when **distributionType** = FIELD. The
            default value is an empty string.
        magnitude
            A Float specifying the electrical potential magnitude. The default value is 0. The
            **magnitude** argument is optional if **distributionType** = USER_DEFINED.
        distributionType
            A SymbolicConstant specifying how the boundary condition is distributed spatially.
            Possible values are UNIFORM, USER_DEFINED, and FIELD. The default value is UNIFORM.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the boundary condition has no amplitude reference. The default
            value is UNSET. You should provide the **amplitude** argument only if it is valid for the
            specified step.
        fixed
            A Boolean specifying whether the boundary condition should remain fixed at the current
            values at the start of the step. The default value is OFF.

        Returns
        -------
        ElectricPotentialBC
            An :py:class:`~abaqus.BoundaryCondition.ElectricPotentialBC.ElectricPotentialBC` object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        fieldName: str = "",
        magnitude: float = 0,
        distributionType: SymbolicConstant = UNIFORM,
        amplitude: str = UNSET,
        fixed: Boolean = OFF,
    ):
        """This method modifies the data for an existing ElectricPotentialBC object in the step
        where it is created.

        Parameters
        ----------
        fieldName
            A String specifying the name of the AnalyticalField object associated with this boundary
            condition. The **fieldName** argument applies only when **distributionType** = FIELD. The
            default value is an empty string.
        magnitude
            A Float specifying the electrical potential magnitude. The default value is 0. The
            **magnitude** argument is optional if **distributionType** = USER_DEFINED.
        distributionType
            A SymbolicConstant specifying how the boundary condition is distributed spatially.
            Possible values are UNIFORM, USER_DEFINED, and FIELD. The default value is UNIFORM.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the boundary condition has no amplitude reference. The default
            value is UNSET. You should provide the **amplitude** argument only if it is valid for the
            specified step.
        fixed
            A Boolean specifying whether the boundary condition should remain fixed at the current
            values at the start of the step. The default value is OFF.
        """
        ...

    @abaqus_method_doc
    def setValuesInStep(
        self,
        stepName: str,
        magnitude: typing.Union[SymbolicConstant, float] = UNCHANGED,
        amplitude: str = "",
    ):
        """This method modifies the propagating data for an existing ElectricPotentialBC object in
        the specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the boundary condition is modified.
        magnitude
            A Float or the SymbolicConstant FREED specifying the electrical potential magnitude.
        amplitude
            A String or a SymbolicConstant specifying the name of the amplitude reference. Possible
            values for the SymbolicConstant are UNCHANGED and FREED. UNCHANGED should be used if the
            amplitude is propagated from the previous analysis step. FREED should be used if the
            boundary condition is changed to have no amplitude reference. You should provide the
            **amplitude** argument only if it is valid for the specified step.
        """
        ...



import typing

from .Load import Load
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class LineLoad(Load):
    """The LineLoad object stores the data of an applied line load.
    The LineLoad object is derived from the Load object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].loads[name]
    """

    #: A String specifying the load repository key.
    name: str = ""

    #: A SymbolicConstant specifying how the load is distributed spatially. Possible values are
    #: UNIFORM, USER_DEFINED, and FIELD. The default value is UNIFORM.
    distributionType: SymbolicConstant = UNIFORM

    #: A SymbolicConstant specifying whether the load is applied in a global or the beam local
    #: frame of reference. Possible values are GLOBAL and LOCAL. The default value is GLOBAL.
    system: SymbolicConstant = GLOBAL

    #: A String specifying the name of the AnalyticalField object associated with this load.
    #: The **field** argument applies only when **distributionType** = FIELD. The default value is an
    #: empty string.
    field: str = ""

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the load is applied.
    region: Region = Region()

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        region: Region,
        distributionType: SymbolicConstant = UNIFORM,
        field: str = "",
        comp1: float = None,
        comp2: float = None,
        comp3: float = None,
        amplitude: str = UNSET,
        system: SymbolicConstant = GLOBAL,
    ):
        """This method creates a LineLoad object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].LineLoad

        Parameters
        ----------
        name
            A String specifying the load repository key.
        createStepName
            A String specifying the name of the step in which the load is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the load is applied.
        distributionType
            A SymbolicConstant specifying how the load is distributed spatially. Possible values are
            UNIFORM, USER_DEFINED, and FIELD. The default value is UNIFORM.
        field
            A String specifying the name of the AnalyticalField object associated with this load.
            The **field** argument applies only when **distributionType** = FIELD. The default value is an
            empty string.
        comp1
            A Float or a Complex specifying the component of the load in the global or the beam
            local 1-direction.Note:Although **comp1**, **comp2**, and **comp3** are optional arguments, at
            least one of them must be nonzero unless **distributionType** = USER_DEFINED.
        comp2
            A Float or a Complex specifying the component of the load in the global or the beam
            local 2-direction.
        comp3
            A Float or a Complex specifying the component of the load in the global 3-direction.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.
        system
            A SymbolicConstant specifying whether the load is applied in a global or the beam local
            frame of reference. Possible values are GLOBAL and LOCAL. The default value is GLOBAL.

        Returns
        -------
        LineLoad
            A :py:class:`~abaqus.Load.LineLoad.LineLoad` object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        distributionType: SymbolicConstant = UNIFORM,
        field: str = "",
        comp1: float = None,
        comp2: float = None,
        comp3: float = None,
        amplitude: str = UNSET,
        system: SymbolicConstant = GLOBAL,
    ):
        """This method modifies the data for an existing LineLoad object in the step where it is
        created.

        Parameters
        ----------
        distributionType
            A SymbolicConstant specifying how the load is distributed spatially. Possible values are
            UNIFORM, USER_DEFINED, and FIELD. The default value is UNIFORM.
        field
            A String specifying the name of the AnalyticalField object associated with this load.
            The **field** argument applies only when **distributionType** = FIELD. The default value is an
            empty string.
        comp1
            A Float or a Complex specifying the component of the load in the global or the beam
            local 1-direction.Note:Although **comp1**, **comp2**, and **comp3** are optional arguments, at
            least one of them must be nonzero unless **distributionType** = USER_DEFINED.
        comp2
            A Float or a Complex specifying the component of the load in the global or the beam
            local 2-direction.
        comp3
            A Float or a Complex specifying the component of the load in the global 3-direction.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.
        system
            A SymbolicConstant specifying whether the load is applied in a global or the beam local
            frame of reference. Possible values are GLOBAL and LOCAL. The default value is GLOBAL.
        """
        ...

    @abaqus_method_doc
    def setValuesInStep(
        self,
        stepName: str,
        comp1: typing.Union[SymbolicConstant, float] = None,
        comp2: typing.Union[SymbolicConstant, float] = None,
        comp3: typing.Union[SymbolicConstant, float] = None,
        amplitude: str = "",
    ):
        """This method modifies the propagating data for an existing LineLoad object in the
        specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the load is modified.
        comp1
            A Float, a Complex, or a SymbolicConstant specifying the load component in the global or
            the beam local 1-direction. Possible values for the SymbolicConstant are UNCHANGED and
            FREED. UNCHANGED should be used if the load component is propagated from the previous
            static analysis step. Use FREED to remove a previously defined load component.
        comp2
            A Float, a Complex, or a SymbolicConstant specifying the load component in the global or
            the beam local 2-direction. For details see **comp1**.
        comp3
            A Float, a Complex, or a SymbolicConstant specifying the load component in the global
            3-direction. For details see **comp1**.
        amplitude
            A String or a SymbolicConstant specifying the name of the amplitude reference. Possible
            values for the SymbolicConstant are UNCHANGED and FREED. UNCHANGED should be used if the
            amplitude is propagated from the previous static analysis step. FREED should be used if
            the load is changed to have no amplitude reference. You should provide the **amplitude**
            argument only if it is valid for the specified step.
        """
        ...



from .ConnectorBehaviorOption import ConnectorBehaviorOption
from .ConnectorOptions import ConnectorOptions
from .ConnectorPotentialArray import ConnectorPotentialArray
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class ConnectorDamage(ConnectorBehaviorOption):
    """The ConnectorDamage object defines damage behavior for one or more components of a
    connector's relative motion.
    The ConnectorDamage object is derived from the ConnectorBehaviorOption object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import section
            mdb.models[name].sections[name].behaviorOptions[i]
            import odbSection
            session.odbs[name].sections[name].behaviorOptions[i]

        The table data for this object are:
        
        Table data for **initiationTable**:
        
        - If **criterion** = FORCE, then each sequence of the table data specifies the following:
            
            - Lower (compression) limiting force or moment. Use -1.0E+36 to indicate an unspecified lower limit.
            - Upper (tension) limiting force or moment. Use 1.0E+36 to indicate an unspecified upper limit. At least one
                limit, lower or upper, must be specified.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
            
        - If **criterion** = MOTION, then each sequence of the table data specifies the following:
        
            - Lower (compression) limiting connector constitutive relative displacement or rotation. Use -1.0E+36 to
                indicate an unspecified lower limit.
            - Upper (tension) limiting connector constitutive relative displacement or rotation. Use 1.0E+36 to indicate an
                unspecified upper limit. At least one limit, lower or upper, must be specified.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **criterion** = PLASTIC_MOTION, then each sequence of the table data specifies the following:
        
            - Relative equivalent Plastic displacement/rotation at which damage will be initiated.
            - Mode-mix ratio (only if **coupling** = COUPLED).
            - Relative equivalent Plastic displacement/rotation rate.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
            
        Table data for **evolutionTable**:
        
        - If **evolutionType** = MOTION and **softening** = LINEAR, then each sequence of the table data specifies the following:
        
            - Post-initiation equivalent relative Plastic motion at ultimate failure if **criterion** = PLASTIC_MOTION.
                Otherwise, post-initiation constitutive relative motion (displacement/rotation) at ultimate failure.
            - Mode-mix ratio (only if **coupling** = COUPLED and **criterion** = PLASTIC_MOTION).
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **evolutionType** = MOTION and **softening** = EXPONENTIAL, then each sequence of the table data specifies the following:
        
            - Post-initiation equivalent relative Plastic motion at ultimate failure if **criterion** = PLASTIC_MOTION.
                Otherwise, post-initiation constitutive relative motion (displacement/rotation) at ultimate failure.
            - Exponential law parameter.
            - Mode-mix ratio (only if **coupling** = COUPLED and **criterion** = PLASTIC_MOTION).
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **evolutionType** = MOTION and **softening** = TABULAR, then each sequence of the table data specifies the following:
        
            - Damage variable (cannot be less than 0 or greater than 1).
            - Post-initiation equivalent relative Plastic motion if **criterion** = PLASTIC_MOTION.  
                Otherwise, post-initiation constitutive relative motion (displacement/rotation).
            - Mode-mix ratio (only if **coupling** = COUPLED and **criterion** = PLASTIC_MOTION).
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **evolutionType** = ENERGY, then each sequence of the table data specifies the following:
        
            - Total energy dissipated by damage at ultimate failure.
            - Mode-mix ratio (only if **coupling** = COUPLED and **criterion** = PLASTIC_MOTION).
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.

        The corresponding analysis keywords are:

        - CONNECTOR DAMAGE INITIATION
    """

    #: A :py:class:`~abaqus.Connector.ConnectorOptions.ConnectorOptions` object specifying the ConnectorOptions used to define tabular options
    #: for the damage initiation table.
    initiationOptions: ConnectorOptions = ConnectorOptions()

    #: A :py:class:`~abaqus.Connector.ConnectorOptions.ConnectorOptions` object specifying the ConnectorOptions used to define tabular options
    #: for the damage evolution table.
    evolutionOptions: ConnectorOptions = ConnectorOptions()

    #: A SymbolicConstant specifying whether or not the behavior is coupled. Possible values
    #: are UNCOUPLED and COUPLED. The default value is UNCOUPLED.
    coupling: SymbolicConstant = UNCOUPLED

    #: A SymbolicConstant specifying the damage initiation criterion to be used. Possible
    #: values are FORCE, MOTION, and PLASTIC_MOTION. The default value is FORCE.
    criterion: SymbolicConstant = FORCE

    #: A Boolean specifying whether the initiation data depend on temperature. The default
    #: value is OFF.
    initiationTemperature: Boolean = OFF

    #: A SymbolicConstant specifying the contribution operator for the initiation potential
    #: contributions. Possible values are SUM and MAXIMUM. The default value is SUM.This
    #: argument is only if **coupling** = COUPLED and if **criterion** = FORCE or MOTION.
    initiationPotentialOperator: SymbolicConstant = SUM

    #: A Float specifying the number equal to the inverse of the overall exponent in the
    #: initiation potential definition. The default value is 2.0.This argument is applicable
    #: only if **coupling** = COUPLED, when **initiationPotentialOperator** = SUM, and when
    #: **criterion** = FORCE or MOTION.
    initiationPotentialExponent: float = 2

    #: An Int specifying the number of field variable dependencies for the initiation data. The
    #: default value is 0.
    initiationDependencies: int = 0

    #: A Boolean specifying whether damage evolution data will be used. The default value is
    #: ON.
    evolution: Boolean = ON

    #: A SymbolicConstant specifying the type of damage evolution to be specified. Possible
    #: values are MOTION_TYPE and ENERGY_TYPE. The default value is MOTION_TYPE.This argument
    #: is applicable only if **evolution** = ON.
    evolutionType: SymbolicConstant = MOTION_TYPE

    #: A SymbolicConstant specifying the damage evolution law to be specified. Possible values
    #: are LINEAR, EXPONENTIAL, and TABULAR. The default value is LINEAR.This argument is
    #: applicable only if **evolution** = ON and when **evolutionType** = MOTION_TYPE.
    softening: SymbolicConstant = LINEAR

    #: A Boolean specifying whether or not **affectedComponents** will be specified. If
    #: **useAffected** = OFF, then only the components of relative motion specified by **components**
    #: will undergo damage. The default value is OFF.This argument is applicable only if
    #: **evolution** = ON.
    useAffected: Boolean = OFF

    #: A SymbolicConstant specifying the contribution of each damage mechanism when more than
    #: one damage mechanism is defined. Possible values are MAXIMUM and MULTIPLICATIVE. The
    #: default value is MAXIMUM.This argument is applicable if **evolution** = ON.
    degradation: SymbolicConstant = MAXIMUM

    #: A Boolean specifying whether the evolution data depend on temperature. The default value
    #: is OFF.This argument is applicable only if **evolution** = ON.
    evolutionTemperature: Boolean = OFF

    #: An Int specifying the number of field variable dependencies for the evolution data. The
    #: default value is 0.This argument is applicable only if **evolution** = ON.
    evolutionDependencies: int = 0

    #: A SymbolicConstant specifying the contribution operator for the evolution potential
    #: contributions. Possible values are SUM and MAXIMUM. The default value is SUM.This
    #: argument is applicable only if **coupling** = COUPLED, when **evolution** = ON, when
    #: **evolutionType** = MOTION_TYPE, and when **criterion** = FORCE or MOTION.
    evolutionPotentialOperator: SymbolicConstant = SUM

    #: A Float specifying the number equal to the inverse of the overall exponent in the
    #: evolution potential definition. The default value is 2.0.This argument is applicable
    #: only if **coupling** = COUPLED, when **evolution** = ON, when **evolutionPotentialOperator** = SUM,
    #: when **evolutionType** = MOTION, and when **criterion** = FORCE or MOTION.
    evolutionPotentialExponent: float = 2

    #: A :py:class:`~abaqus.Connector.ConnectorPotentialArray.ConnectorPotentialArray` object specifying one ConnectorPotential object for each
    #: initiation potential contribution. This member can be specified only if
    #: **coupling** = COUPLED and if **criterion** = FORCE or MOTION.
    initiationPotentials: ConnectorPotentialArray = None

    #: A :py:class:`~abaqus.Connector.ConnectorPotentialArray.ConnectorPotentialArray` object specifying one ConnectorPotential object for each
    #: evolution potential contribution). This member can be specified only if
    #: **coupling** = COUPLED, if **evolution** = ON, if **evolutionType** = MOTION, and if
    #: **criterion** = FORCE or MOTION.
    evolutionPotentials: ConnectorPotentialArray = None

    #: A sequence of sequences of Floats specifying the initiation properties. The default
    #: value is an empty sequence.Items in the **initiationTable** data are described below.
    initiationTable: tuple = ()

    #: A sequence of sequences of Floats specifying the evolution properties. The default value
    #: is an empty sequence.Items in the **evolutionTable** data are described below. This
    #: argument is only applicable if **evolution** = ON.
    evolutionTable: tuple = ()

    #: A sequence of Ints specifying the components of relative motion that will be damaged.
    #: Possible values are 1 ≤ **components** ≤ 6. Only available components can be specified.
    #: This argument is applicable only if **evolution** = ON and **useAffected** = ON. The default
    #: value is an empty sequence.
    affectedComponents: tuple = ()

    #: A sequence of Ints specifying the components of relative motion for which the behavior
    #: is defined. Possible values are 1 ≤ **components** ≤ 6. Only available components can be
    #: specified. This argument can be specified only if **coupling** = UNCOUPLED. The default
    #: value is an empty sequence.
    components: tuple = ()

    @abaqus_method_doc
    def __init__(
        self,
        coupling: SymbolicConstant = UNCOUPLED,
        criterion: SymbolicConstant = FORCE,
        initiationTemperature: Boolean = OFF,
        initiationPotentialOperator: SymbolicConstant = SUM,
        initiationPotentialExponent: float = 2,
        initiationDependencies: int = 0,
        evolution: Boolean = ON,
        evolutionType: SymbolicConstant = MOTION_TYPE,
        softening: SymbolicConstant = LINEAR,
        useAffected: Boolean = OFF,
        degradation: SymbolicConstant = MAXIMUM,
        evolutionTemperature: Boolean = OFF,
        evolutionDependencies: int = 0,
        evolutionPotentialOperator: SymbolicConstant = SUM,
        evolutionPotentialExponent: float = 2,
        initiationPotentials: ConnectorPotentialArray = None,
        evolutionPotentials: ConnectorPotentialArray = None,
        initiationTable: tuple = (),
        evolutionTable: tuple = (),
        affectedComponents: tuple = (),
        components: tuple = (),
    ):
        """This method creates a connector damage behavior option for a ConnectorSection object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                import connectorBehavior
                connectorBehavior.ConnectorDamage
                import odbConnectorBehavior
                odbConnectorBehavior.ConnectorDamage

        Parameters
        ----------
        coupling
            A SymbolicConstant specifying whether or not the behavior is coupled. Possible values
            are UNCOUPLED and COUPLED. The default value is UNCOUPLED.
        criterion
            A SymbolicConstant specifying the damage initiation criterion to be used. Possible
            values are FORCE, MOTION, and PLASTIC_MOTION. The default value is FORCE.
        initiationTemperature
            A Boolean specifying whether the initiation data depend on temperature. The default
            value is OFF.
        initiationPotentialOperator
            A SymbolicConstant specifying the contribution operator for the initiation potential
            contributions. Possible values are SUM and MAXIMUM. The default value is SUM.This
            argument is only if **coupling** = COUPLED and if **criterion** = FORCE or MOTION.
        initiationPotentialExponent
            A Float specifying the number equal to the inverse of the overall exponent in the
            initiation potential definition. The default value is 2.0.This argument is applicable
            only if **coupling** = COUPLED, when **initiationPotentialOperator** = SUM, and when
            **criterion** = FORCE or MOTION.
        initiationDependencies
            An Int specifying the number of field variable dependencies for the initiation data. The
            default value is 0.
        evolution
            A Boolean specifying whether damage evolution data will be used. The default value is
            ON.
        evolutionType
            A SymbolicConstant specifying the type of damage evolution to be specified. Possible
            values are MOTION_TYPE and ENERGY_TYPE. The default value is MOTION_TYPE.This argument
            is applicable only if **evolution** = ON.
        softening
            A SymbolicConstant specifying the damage evolution law to be specified. Possible values
            are LINEAR, EXPONENTIAL, and TABULAR. The default value is LINEAR.This argument is
            applicable only if **evolution** = ON and when **evolutionType** = MOTION_TYPE.
        useAffected
            A Boolean specifying whether or not **affectedComponents** will be specified. If
            **useAffected** = OFF, then only the components of relative motion specified by **components**
            will undergo damage. The default value is OFF.This argument is applicable only if
            **evolution** = ON.
        degradation
            A SymbolicConstant specifying the contribution of each damage mechanism when more than
            one damage mechanism is defined. Possible values are MAXIMUM and MULTIPLICATIVE. The
            default value is MAXIMUM.This argument is applicable if **evolution** = ON.
        evolutionTemperature
            A Boolean specifying whether the evolution data depend on temperature. The default value
            is OFF.This argument is applicable only if **evolution** = ON.
        evolutionDependencies
            An Int specifying the number of field variable dependencies for the evolution data. The
            default value is 0.This argument is applicable only if **evolution** = ON.
        evolutionPotentialOperator
            A SymbolicConstant specifying the contribution operator for the evolution potential
            contributions. Possible values are SUM and MAXIMUM. The default value is SUM.This
            argument is applicable only if **coupling** = COUPLED, when **evolution** = ON, when
            **evolutionType** = MOTION_TYPE, and when **criterion** = FORCE or MOTION.
        evolutionPotentialExponent
            A Float specifying the number equal to the inverse of the overall exponent in the
            evolution potential definition. The default value is 2.0.This argument is applicable
            only if **coupling** = COUPLED, when **evolution** = ON, when **evolutionPotentialOperator** = SUM,
            when **evolutionType** = MOTION, and when **criterion** = FORCE or MOTION.
        initiationPotentials
            A :py:class:`~abaqus.Connector.ConnectorPotentialArray.ConnectorPotentialArray` object specifying one ConnectorPotential object for each
            initiation potential contribution. This member can be specified only if
            **coupling** = COUPLED and if **criterion** = FORCE or MOTION.
        evolutionPotentials
            A :py:class:`~abaqus.Connector.ConnectorPotentialArray.ConnectorPotentialArray` object specifying one ConnectorPotential object for each
            evolution potential contribution). This member can be specified only if
            **coupling** = COUPLED, if **evolution** = ON, if **evolutionType** = MOTION, and if
            **criterion** = FORCE or MOTION.
        initiationTable
            A sequence of sequences of Floats specifying the initiation properties. The default
            value is an empty sequence.Items in the **initiationTable** data are described below.
        evolutionTable
            A sequence of sequences of Floats specifying the evolution properties. The default value
            is an empty sequence.Items in the **evolutionTable** data are described below. This
            argument is only applicable if **evolution** = ON.
        affectedComponents
            A sequence of Ints specifying the components of relative motion that will be damaged.
            Possible values are 1 ≤ **components** ≤ 6. Only available components can be specified.
            This argument is applicable only if **evolution** = ON and **useAffected** = ON. The default
            value is an empty sequence.
        components
            A sequence of Ints specifying the components of relative motion for which the behavior
            is defined. Possible values are 1 ≤ **components** ≤ 6. Only available components can be
            specified. This argument can be specified only if **coupling** = UNCOUPLED. The default
            value is an empty sequence.

        Returns
        -------
        ConnectorDamage
            A :py:class:`~abaqus.Connector.ConnectorDamage.ConnectorDamage` object.

        Raises
        ------
        ValueError and TextError
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the ConnectorDamage object.

        Raises
        ------
        ValueError
        """
        ...



from .....UtilityAndView.abaqusConstants import *
from ....._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class Ornl:
    """The Ornl object specifies the constitutive model developed by Oak Ridge National
    Laboratory.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].creep.ornl
            mdb.models[name].materials[name].Plastic.ornl
            import odbMaterial
            session.odbs[name].materials[name].creep.ornl
            session.odbs[name].materials[name].Plastic.ornl

        The corresponding analysis keywords are:

        - ORNL
    """

    @abaqus_method_doc
    def __init__(self, a: float = 0, h: float = None, reset: Boolean = OFF):
        """This method creates an Ornl object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].creep.Ornl
                mdb.models[name].materials[name].Plastic.Ornl
                session.odbs[name].materials[name].creep.Ornl
                session.odbs[name].materials[name].Plastic.Ornl

        Parameters
        ----------
        a
            A Float specifying the saturation rates for kinematic shift caused by creep strain, as
            defined by Equation (15) of Section 4.3.3-3 of the Nuclear Standard. The default value
            corresponds to that section of the Standard. Set **a** = 0.0 to use the 1986 revision of the
            Standard. The default value is 0.3.
        h
            None or a Float specifying the rate of kinematic shift with respect to creep strain
            [Equation (7) of Section 4.3.2-1 of the Nuclear Standard]. If **h** = None, the value of **h**
            is determined according to Section 4.3.3-3 of the 1981 revision of the Standard. Set
            **h** = 0.0 to use the 1986 revision of the Standard. The default value is None.
        reset
            A Boolean specifying whether to invoke the optional αα reset procedure described in
            Section 4.3.5 of the Nuclear Standard. The default value is OFF.

        Returns
        -------
        Ornl
            An :py:class:`~abaqus.Material.Plastic.Metal.ORNL.Ornl.Ornl` object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the Ornl object.

        Raises
        ------
        RangeError
        """
        ...



from .InteractionState import InteractionState
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc


@abaqus_class_doc
class FluidExchangeState(InteractionState):
    """The FluidExchangeState object stores the propagating data for an FluidExchange object.
    One instance of this object is created internally by the FluidExchange object for each
    step. The instance is also deleted internally by the FluidExchange object.
    The FluidExchangeState object has no constructor or methods.
    The FluidExchangeState object is derived from the InteractionState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].steps[name].interactionStates[name]
    """

    #: A SymbolicConstant specifying the propagation state of the InteractionState object.
    #: Possible values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None



from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc


@abaqus_class_doc
class InteractionState:
    """The InteractionState object is the abstract base type for other InteractionState
    objects. The InteractionState object has no explicit constructor. The members of the
    InteractionState object are common to all objects derived from InteractionState.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].steps[name].interactionStates[name]
    """

    #: A SymbolicConstant specifying the propagation state of the InteractionState object.
    #: Possible values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None



from .BoundaryConditionState import BoundaryConditionState
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc


@abaqus_class_doc
class EulerianBCState(BoundaryConditionState):
    """The EulerianBCState object stores the propagating data for an Eulerian boundary
    condition in a step. One instance of this object is created internally by the EulerianBC
    object for each step. The instance is also deleted internally by the EulerianBC object.
    The EulerianBCState object has no constructor or methods.
    The EulerianBCState object is derived from the BoundaryConditionState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].steps[name].boundaryConditionStates[name]

        The corresponding analysis keywords are:

        - EULERIAN BOUNDARY
    """

    #: A SymbolicConstant specifying the material flow conditions to be defined. Possible
    #: values are INFLOW, OUTFLOW, and BOTH. The default value is INFLOW.
    definition: SymbolicConstant = INFLOW

    #: A SymbolicConstant specifying the propagation state of the definition member. Possible
    #: values are UNSET, SET, and UNCHANGED.
    definitionState: SymbolicConstant = None

    #: A SymbolicConstant specifying the material flow conditions to be defined. Possible
    #: values are FREE, NONE, and VOID. The default value is FREE.
    inflowType: SymbolicConstant = FREE

    #: A SymbolicConstant specifying the propagation state of the definition member. Possible
    #: values are UNSET, SET, and UNCHANGED.
    inflowTypeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the material flow conditions to be defined. Possible
    #: values are ZERO_PRESSURE, FREE, NON_REFLECTING, and EQUILIBRIUM. The default value is
    #: ZERO_PRESSURE.
    outflowType: SymbolicConstant = ZERO_PRESSURE

    #: A SymbolicConstant specifying the propagation state of the definition member. Possible
    #: values are UNSET, SET, and UNCHANGED.
    outflowTypeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the amplitude reference. Possible
    #: values are UNSET, SET, UNCHANGED, FREED, and MODIFIED.
    amplitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the BoundaryConditionState object. Possible values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - PROPAGATED_FROM_BASE_STATE
    #: - MODIFIED_FROM_BASE_STATE
    #: - DEACTIVATED_FROM_BASE_STATE
    #: - BUILT_INTO_MODES
    status: SymbolicConstant = None

    #: A String specifying the name of the amplitude reference. The String is empty if the
    #: boundary condition has no amplitude reference.
    amplitude: str = ""



from ...UtilityAndView.abaqusConstants import *
from ..._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class GasketTransverseShearElastic:
    """The GasketTransverseShearElastic object defines the elastic parameters for the
    transverse shear behavior of a gasket.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].gasketTransverseShearElastic
            import odbMaterial
            session.odbs[name].materials[name].gasketTransverseShearElastic

        The table data for this object are:

        - Shear stiffness. (This value cannot be negative.)
        - Temperature, if the data depend on temperature.
        - Value of the first field variable, if the data depend on field variables.
        - Value of the second field variable.
        - Etc.

        The corresponding analysis keywords are:

        - GASKET ELASTICITY
    """

    @abaqus_method_doc
    def __init__(
        self,
        table: tuple,
        variableUnits: SymbolicConstant = STRESS,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
    ):
        """This method creates a GasketTransverseShearElastic object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].GasketTransverseShearElastic
                session.odbs[name].materials[name].GasketTransverseShearElastic

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        variableUnits
            A SymbolicConstant specifying the unit system in which the transverse shear behavior
            will be defined. Possible values are STRESS and FORCE. The default value is STRESS.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        GasketTransverseShearElastic
            A :py:class:`~abaqus.Material.Gasket.GasketTransverseShearElastic.GasketTransverseShearElastic` object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the GasketTransverseShearElastic object.

        Raises
        ------
        RangeError
        """
        ...



from ....UtilityAndView.abaqusConstants import *
from ...._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class SoretEffect:
    r"""The SoretEffect object defines temperature gradient driven mass diffusion.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].diffusivity.soretEffect
            import odbMaterial
            session.odbs[name].materials[name].diffusivity.soretEffect

        The table data for this object are:

        - Soret effect factor, :math:`\kappa_s`.
        - Concentration.
        - Temperature, if the data depend on temperature.
        - Value of the first field variable, if the data depend on field variables.
        - Value of the second field variable.
        - Etc.

        The corresponding analysis keywords are:

        - KAPPA
    """

    @abaqus_method_doc
    def __init__(
        self, table: tuple, temperatureDependency: Boolean = OFF, dependencies: int = 0
    ):
        """This method creates a SoretEffect object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].diffusivity.SoretEffect
                session.odbs[name].materials[name].diffusivity.SoretEffect

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        SoretEffect
            A :py:class:`~abaqus.Material.Others.MassDiffusion.SoretEffect.SoretEffect` object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the SoretEffect object.

        Raises
        ------
        RangeError
        """
        ...
